@@ -186,39 +186,39 @@ class RFPDupeFilter(BaseDupeFilter):
             self.logger.debug(msg, {'request': request}, extra={'spider': spider})
             self.logdupes = False
 
-    def _request_seen(self, request):
-        """Returns True if request was already seen.
-
-        Parameters
-        ----------
-        request : scrapy.http.Request
-
-        Returns
-        -------
-        bool
-
-        """
-        fp = self.request_fingerprint(request)
-        if self._isContains(fp):
-            return True
-        self._insert(fp)
-        return False
-
-    def _isContains(self, str_input):
-        if not str_input:
-            return False
-
-        name = self.key + str(sum(map(ord, str_input)) % self.blockNum)
-        for seed in range(self.seeds):
-            loc = mmh3.hash(str_input, seed, signed=False)
-            if self.server.getbit(name+'_crawled', loc % self.bit_size) == 0:
-                break
-        else:
-            return True
-        return False
-
-    def _insert(self, str_input):
-        name = self.key + str(sum(map(ord, str_input)) % self.blockNum)
-        for seed in range(self.seeds):
-            loc = mmh3.hash(str_input, seed, signed=False)
-            self.server.setbit(name+'_crawled', loc % self.bit_size, 1)
+    # def _request_seen(self, request):
+    #     """Returns True if request was already seen.
+    #
+    #     Parameters
+    #     ----------
+    #     request : scrapy.http.Request
+    #
+    #     Returns
+    #     -------
+    #     bool
+    #
+    #     """
+    #     fp = self.request_fingerprint(request)
+    #     if self._isContains(fp):
+    #         return True
+    #     self._insert(fp)
+    #     return False
+    #
+    # def _isContains(self, str_input):
+    #     if not str_input:
+    #         return False
+    #
+    #     name = self.key + str(sum(map(ord, str_input)) % self.blockNum)
+    #     for seed in range(self.seeds):
+    #         loc = mmh3.hash(str_input, seed, signed=False)
+    #         if self.server.getbit(name+'_crawled', loc % self.bit_size) == 0:
+    #             break
+    #     else:
+    #         return True
+    #     return False
+    #
+    # def _insert(self, str_input):
+    #     name = self.key + str(sum(map(ord, str_input)) % self.blockNum)
+    #     for seed in range(self.seeds):
+    #         loc = mmh3.hash(str_input, seed, signed=False)
+    #         self.server.setbit(name+'_crawled', loc % self.bit_size, 1)
